[Astronomy Picture of the Day][`APOD`] is one the [![nasa](https://avatars0.githubusercontent.com/u/848102?s=30&v=4) APIs](https://api.nasa.gov/).  This notebook explores the information contained in the API.  

Project Jupyter has a tutorial that teaches you to [build JupyterLab extensions using `APOD`](https://jupyterlab.readthedocs.io/en/stable/developer/extension_tutorial.html), or install the [chrome extension](https://chrome.google.com/webstore/detail/nasa-picture-of-the-day/njgkhaihjhccfmimhnddjgmdmnplhdel?hl=en), or `continue` reading this essay to make a static HTML gallery of 🛰👽🚀🖼.

[`APOD`]: https://apod.nasa.gov/apod/astropix.html


```python
%reload_ext tonyfast
__import__('requests_cache').install_cache('nasa'); import pandas, IPython
today = "https://api.nasa.gov/planetary/apod".download_json(params=dict(date='', api_key=__import__('os').environ['nasa'])).series()
```

#### Explore below to learn more about the api.

> You'll notice the need for a developer api key for ![nasa](https://avatars0.githubusercontent.com/u/848102?s=30&v=4)- which feels pretty bad ass.


```python
APOD = "https://api.nasa.gov/assets/json/apis.json".download_json().frame().set_index('name').loc['APOD']
IPython.display.HTML(F"""<details><summary>More about the APOD API</summary>{APOD.html_template}</details>""")
```




<details><summary>More about the APOD API</summary><h1 id="apod">APOD</h1><p>One of the most popular websites at NASA is the <a href="http://apod.nasa.gov/apod/astropix.html">Astronomy Picture of the Day</a>. In fact, this website is one of the <a href="https://analytics.usa.gov">most popular websites</a> across all federal agencies. It has the popular appeal of a Justin Bieber video. This endpoint structures the APOD imagery and associated metadata so that it can be repurposed for other applications. In addition, if the <code class="prettyprint">concept_tags</code> parameter is set to <code class="prettyprint">True</code>, then keywords derived from the image explanation are returned. These keywords could be used as auto-generated hashtags for twitter or instagram feeds; but generally help with discoverability of relevant imagery.</p><p><strong>Example image:</strong></p><p><img src="assets/img/general/apod.jpg"/></p><h3 id="http-request">HTTP Request</h3><p><code class="prettyprint"> GET https://api.nasa.gov/planetary/apod </code></p><p><b>concept_tags are now disabled in this service. Also, an optional return parameter <i>copyright</i> is returned if the image is not public domain.</b></p><h3 id="query-parameters">Query Parameters</h3><table> <thead> <tr> <th>Parameter</th> <th>Type</th> <th>Default</th> <th>Description</th> </tr></thead> <tbody> <tr> <td>date</td><td>YYYY-MM-DD</td><td><em>today</em></td><td>The date of the APOD image to retrieve</td></tr><!-- <tr> <td><del>concept_tags</del></td><td>bool</td><td>False</td><td>Return an ordered dictionary of concepts from the APOD explanation</td></tr>--> <tr> <td>hd</td><td>bool</td><td>False</td><td>Retrieve the URL for the high resolution image</td></tr><tr> <td>api_key</td><td>string</td><td>DEMO_KEY</td><td>api.nasa.gov key for expanded usage</td></tr></tbody></table><h3 id="example-query">Example query</h3><p><a href="https://api.nasa.gov/planetary/apod?api_key=DEMO_KEY"> <code class="prettyprint">https://api.nasa.gov/planetary/apod?api_key=DEMO_KEY </code></a></p></details>



## Download ~2 months of images.


```python
df = [
    *map("https://api.nasa.gov/planetary/apod?date=".__add__, pandas.date_range(end=today.date, start='2019-07-01', freq='1D').strftime('%Y-%m-%d'))
].download_json(params=dict(api_key=__import__('os').environ['nasa'])).frame().set_index('date').pipe(lambda df: df[df.copyright.isna()]).iloc[::-1]
display("The table below samples rows from the APOD API responses.  We've excluded copyrighted images.", df.sample(3).T)
```


    "The table below samples rows from the APOD API responses.  We've excluded copyrighted images."



<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>date</th>
      <th>2019-07-17</th>
      <th>2019-09-17</th>
      <th>2019-07-03</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>copyright</td>
      <td>NaN</td>
      <td>NaN</td>
      <td>NaN</td>
    </tr>
    <tr>
      <td>explanation</td>
      <td>It had never been done before. But with the wo...</td>
      <td>Where else might life exist?  One of humanity'...</td>
      <td>If you could fly across Titan, what would you ...</td>
    </tr>
    <tr>
      <td>hdurl</td>
      <td>NaN</td>
      <td>https://apod.nasa.gov/apod/image/1909/K218b_ES...</td>
      <td>NaN</td>
    </tr>
    <tr>
      <td>media_type</td>
      <td>video</td>
      <td>image</td>
      <td>video</td>
    </tr>
    <tr>
      <td>service_version</td>
      <td>v1</td>
      <td>v1</td>
      <td>v1</td>
    </tr>
    <tr>
      <td>title</td>
      <td>Apollo 11: Descent to the Moon</td>
      <td>Water Vapor Discovered on Distant Exoplanet</td>
      <td>Robotic Dragonfly Selected to Fly Across Titan</td>
    </tr>
    <tr>
      <td>url</td>
      <td>https://www.youtube.com/embed/xc1SzgGhMKc?star...</td>
      <td>https://apod.nasa.gov/apod/image/1909/K218b_ES...</td>
      <td>https://www.youtube.com/embed/t9-0p9KjHv8?rel=0</td>
    </tr>
  </tbody>
</table>
</div>


### Create HTML displays of the daily pictures.

* Use [f-strings](https://realpython.com/python-f-strings/) & [flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)


```python
IPython.display.HTML("""<div style="display: flex; flex-direction: row; flex-wrap: wrap;">{}</div>""".format(''.join(
    df.apply(lambda x: F"""<figure style="order: 1;"><img src="{x.url}" alt="{x.title}" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>{x.name}</code>{x.explanation}</figcaption></figure>""", axis=1))))
```




<div style="display: flex; flex-direction: row; flex-wrap: wrap;"><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/DunesThawingOnMars_ExoMars_1080.jpg" alt="Sand Dunes Thawing on Mars" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-24</code>What are these strange shapes on Mars?  Defrosting sand dunes. As Spring dawned on the Northern Hemisphere of Mars, dunes of sand near the pole, as pictured here in late May by ESA's ExoMars Trace Gas Orbiter, began to thaw.  The carbon dioxide and water ice actually sublime in the thin atmosphere directly to gas.  Thinner regions of ice typically defrost first revealing sand whose darkness soaks in sunlight and accelerates the thaw.  The process might even involve sandy jets exploding through the thinning ice.  By Summer, spots will expand to encompass the entire dunes.  The Martian North Pole is ringed by many similar fields of barchan sand dunes, whose strange, smooth arcs are shaped by persistent Martian winds.   Create a Distant Legacy: Send your name to Mars.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/LastRingPortrait_Cassini_1080.jpg" alt="Saturn at Night" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-20</code></figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/K218b_ESAKornmesser_1080.jpg" alt="Water Vapor Discovered on Distant Exoplanet" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-17</code>Where else might life exist?  One of humanity's great outstanding questions, locating planets where extrasolar life might survive took a step forward recently with the discovery of a significant amount of water vapor in the atmosphere of distant exoplanet K2-18b. The planet and it parent star, K2-18, lie about 124 light years away toward the constellation of the Lion (Leo). The exoplanet is significantly larger and more massive than our Earth, but orbits in the habitable zone of its home star. K2-18, although more red than our Sun, shines in K2-18b's sky with a brightness similar to the Sun in Earth's sky.  The discovery was made in data from three space telescopes: Hubble, Spitzer, and Kepler, by noting the absorption of water-vapor colors when the planet moved in front of the star.  The featured illustration imagines exoplanet K2-18b on the right, its parent red dwarf star K2-18 on the left, and an unconfirmed sister planet between them.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/longstorm_cassini_960.jpg" alt="A Long Storm System on Saturn" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-15</code>It was one of the largest and longest lived storms ever recorded in our Solar System.  First seen in late 2010, the above cloud formation in the northern hemisphere of Saturn started larger than the Earth and soon spread completely around the planet. The storm was tracked not only from Earth but from up close by the robotic Cassini spacecraft then orbiting Saturn. Pictured here in false colored infrared in February, orange colors indicate clouds deep in the atmosphere, while light colors highlight clouds higher up. The rings of Saturn are seen nearly edge-on as the thin blue horizontal line. The warped dark bands are the shadows of the rings cast onto the cloud tops by the Sun to the upper left. A source of radio noise from lightning, the intense storm was thought to relate to seasonal changes when spring emerges in the north of  Saturn. After raging for over six months, the iconic storm circled the entire planet and then tried to absorb its own tail -- which surprisingly caused it to fade away.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/PlutoTrueColor_NewHorizons_960.jpg" alt="Pluto in True Color" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-10</code>What color is Pluto, really? It took some effort to figure out.  Even given all of the images sent back to Earth when the robotic New Horizons spacecraft sped past Pluto in 2015, processing these multi-spectral frames to approximate what the human eye would see was challenging. The result featured here, released three years after the raw data was acquired by New Horizons, is the highest resolution true color image of Pluto ever taken. Visible in the image is the light-colored, heart-shaped, Tombaugh Regio, with the unexpectedly smooth Sputnik Planitia, made of frozen nitrogen, filling its western lobe. New Horizons found the dwarf-planet to have a surprisingly complex surface composed of many regions having perceptibly different hues.  In total, though, Pluto is mostly brown, with much of its muted color originating from small amounts of surface methane energized by ultraviolet light from the Sun.</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/OfM7VlonD5c?rel=0" alt="Perijove 11: Passing Jupiter" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-08</code>Here comes Jupiter! NASA's robotic spacecraft Juno is continuing on its 53-day, highly-elongated orbits around our Solar System's largest planet.  The featured video is from perijove 11 in early 2018, the eleventh time Juno has passed near Jupiter since it arrived in mid-2016.  This time-lapse, color-enhanced movie covers about four hours and morphs between 36 JunoCam images. The video begins with Jupiter rising as Juno approaches from the north. As Juno reaches its closest view -- from about 3,500 kilometers over Jupiter's cloud tops -- the spacecraft captures the great planet in tremendous detail. Juno passes light zones and dark belt of clouds that circle the planet, as well as numerous swirling circular storms, many of which are larger than hurricanes on Earth.  After the perijove, Jupiter recedes into the distance, now displaying the unusual clouds that appear over Jupiter's south.  To get desired science data, Juno swoops so close to Jupiter that its instruments are exposed to very high levels of radiation.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/Chandrafirstlight_0_1024.jpg" alt="Recycling Cassiopeia A" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-06</code>Massive stars in our Milky Way Galaxy live spectacular lives.  Collapsing from vast cosmic clouds, their nuclear furnaces ignite and create heavy elements in their cores. After a few million years, the enriched material is blasted back into interstellar space where star formation can begin anew. The expanding debris cloud known as Cassiopeia A is an example of this final phase of the stellar life cycle. Light from the explosion which created this supernova remnant would have been first seen in planet Earth's sky about 350 years ago, although it took that light about 11,000 years to reach us. This false-color image, composed of X-ray and optical image data from the Chandra X-ray Observatory and Hubble Space Telescope, shows the still hot filaments and knots in the remnant. It spans about 30 light-years at the estimated distance of Cassiopeia A. High-energy X-ray emission from specific elements has been color coded, silicon in red, sulfur in yellow, calcium in green and iron in purple, to help astronomers explore the recycling of our galaxy's star stuff. Still expanding, the outer blast wave is seen in blue hues. The bright speck near the center is a neutron star, the incredibly dense, collapsed remains of the massive stellar core.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1909/SpiderFly_Spitzer2Mass_960.jpg" alt="The Spider Nebula in Infrared" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-04</code>Will the spider ever catch the fly? Not if both are large emission nebulas toward the constellation of the Charioteer (Auriga).  The spider-shaped gas cloud on the left is actually an emission nebula labelled IC 417, while a smaller fly-shaped cloud off the image to the left is dubbed  NGC 1931 and is both an emission nebula and a reflection nebula.  About 10,000 light-years distant, both nebulas harbor young, open star clusters. For scale, the more compact NGC 1931 (Fly) is about 10 light-years across. The featured picture in scientifically-assigned, infrared colors combines images from the Spitzer Space Telescope and the Two Micron All Sky Survey (2MASS).  Spitzer is celebrating its 16th year orbiting the Sun near the Earth.    APOD in other languages: Arabic, Catalan, Chinese (Beijing), Chinese (Taiwan), Croatian, Czech, Dutch, Farsi, French, French, German, Hebrew, Indonesian, Japanese, Korean, Montenegrin, Polish, Russian, Serbian, Slovenian,  Spanish and Ukrainian</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/bQ9qcR-KCsA?rel=0" alt="Unusual Signal Suggests Neutron Star Destroyed by Black Hole" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-09-03</code>What created this unusual explosion? Three weeks ago, gravitational wave detectors in the USA and Europe -- the LIGO and Virgo detectors -- detected a burst of gravitational radiation that had the oscillating pattern expected when a black hole destroys a neutron star.  One object in event S190814bv was best fit with a mass greater than five times the mass of the Sun -- making it a good candidate for a black hole, while the other object appeared to have a mass less than three times the mass of the Sun -- making it a good candidate for a neutron star. No similar event had been detected with gravitational waves before.  Unfortunately, no light was seen from this explosion, light that might have been triggered by the disrupting neutron star. It is theoretically possible that the lower mass object was also a black hole, even though no clear example of a black hole with such a low mass is known. The featured video was created to illustrate a previously suspected black hole - neutron star collision detected in light in 2005, specifically gamma-rays from the burst GRB 050724. The animated video starts with a foreground neutron star orbiting a black hole surrounded by an accretion disk. The black hole's gravity then shreds the neutron star, creating a jet as debris falls into the black hole. S190814bv will continue to be researched, with clues about the nature of the objects involved possibly coming from future detections of similar systems.   Follow APOD in English on: Instagram, Facebook,  Reddit, or Twitter</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/orion2010_spitzerMedRC.jpg" alt="Spitzer's Orion" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-31</code>Few cosmic vistas excite the imagination like the Orion Nebula, an immense stellar nursery some 1,500 light-years away. Spanning about 40 light-years across the region, this infrared image from the Spitzer Space Telescope was constructed from data intended to monitor the brightness of the nebula's young stars, many still surrounded by dusty, planet-forming disks. Orion's young stars are only about 1 million years old, compared to the Sun's age of 4.6 billion years. The region's hottest stars are found in the Trapezium Cluster, the brightest cluster near picture center. Launched into orbit around the Sun on August 25, 2003 Spitzer's liquid helium coolant ran out in May 2009. The infrared space telescope continues to operate though, its mission scheduled to end on January 30, 2020. Recorded in 2010, this false color view is from two channels that still remain sensitive to infrared light at Spitzer's warmer operating temperatures.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/M61-HST-ESO-S1024.jpg" alt="Messier 61 Close Up" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-28</code>Image data from the Hubble Space Telescope, the European Southern Observatory, and small telescopes on planet Earth are combined in this magnificent portrait of face-on spiral galaxy Messier 61 (M61). A mere 55 million light-years away in the Virgo Cluster of Galaxies, M61 is also known as NGC 4303. It's considered to be an example of a barred spiral galaxy similar to our own Milky Way. Like other spiral galaxies, M61 also features sweeping spiral arms, cosmic dust lanes, pinkish star forming regions, and young blue star clusters. The bright galactic core is offset to the left in this 50 thousand light-year wide close-up.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/AntaresRho_McGarvey_960.jpg" alt="Dark Dust and Colorful Clouds near Antares" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-27</code>Why is the sky near Antares and Rho Ophiuchi so dusty yet colorful?  The colors result from a mixture of objects and processes.  Fine dust illuminated from the front by starlight produces blue reflection nebulae. Gaseous clouds whose atoms are excited by ultraviolet starlight produce reddish emission nebulae. Backlit dust clouds block starlight and so appear dark.   Antares, a red supergiant and one of the brighter stars in the night sky, lights up the yellow-red clouds on the lower left of the featured image. Rho Ophiuchi lies at the center of the blue nebula near the top.   The distant globular cluster M4 is visible to the right of Antares. These star clouds are even more colorful than humans can see, emitting light across the electromagnetic spectrum.</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/rFDjAfwmWKM?rel=0" alt="Leaving Earth" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-25</code>What it would look like to leave planet Earth? Such an event was recorded visually in great detail by the MESSENGER spacecraft as it swung back past the Earth in 2005 on its way in toward the planet Mercury. Earth can be seen rotating in this time-lapse video, as it recedes into the distance. The sunlit half of Earth is so bright that background stars are not visible. The robotic MESSENGER spacecraft is now in orbit around Mercury and has recently concluded the first complete map of the surface. On occasion, MESSENGER has continued to peer back at its home world. MESSENGER is one of the few things created on the Earth that has left and will never return -- at the end of its mission MESSENGER crashed into Mercury's surface.</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/f8rs3bcEO-o?rel=0" alt="Animation: Spiral Disk around a Black Hole" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-20</code>What would it look like to orbit a black hole? Many black holes are surrounded by swirling pools of gas known as accretion disks. These disks can be extremely hot, and much of the orbiting gas will eventually fall through the black hole's event horizon -- where it will never be seen again. The featured animation is an artist's rendering of the curious disk spiraling around the supermassive black hole at the center of spiral galaxy NGC 3147.  Gas at the inner edge of this disk is so close to the black hole that it moves unusually fast -- at 10 percent of the speed of light. Gas this fast shows relativistic beaming, making the side of the disk heading toward us appear significantly brighter than the side moving away.  The animation is based on images of NGC 3147 made recently with the Hubble Space Telescope.    Astrophysicists: Browse 2,000+ codes in the Astrophysics Source Code Library</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/orion1901_ritchey1024.jpg" alt="1901 Photograph: The Orion Nebula" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-17</code>By the turn of the 20th century advances in photography contributed an important tool for astronomers. Improving photographic materials, long exposures, and new telescope designs produced astronomical images with details not visible at the telescopic eyepiece alone. Remarkably recognizable to astrophotographers today, this stunning image of the star forming Orion Nebula was captured in 1901 by American astronomer and telescope designer George Ritchey. The original glass photographic plate, sensitive to green and blue wavelengths, has been digitized and light-to-dark inverted to produce a positive image. His hand written notes indicate a 50 minute long exposure that ended at dawn and a reflecting telescope aperture of 24 inches masked to 18 inches to improve the sharpness of the recorded image. Ritchey's plates from over a hundred years ago preserve astronomical data and can still be used for exploring astrophysical processes.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/MoonSaturn_Patonai_960.jpg" alt="Saturn Behind the Moon" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-14</code>What's that next to the Moon? Saturn. In its monthly trip around the Earth -- and hence Earth's sky -- our Moon passed nearly in front of Sun-orbiting Saturn earlier this week.  Actually the Moon passed directly in front of Saturn from the viewpoints of a wide swath of Earth's Southern Hemisphere.  The featured image from Sydney, Australia captured the pair a few minutes before the eclipse.  The image was a single shot lasting only 1/500th of a second, later processed to better highlight both the Moon and Saturn. Since Saturn is nearly opposite the Sun, it can be seen nearly the entire night, starting at sunset, toward the south and east.  The gibbous Moon was also nearly opposite the Sun, and so also visible nearly the entire night -- it will be full tomorrow night. The Moon will occult Saturn again during every lap it makes around the Earth this year.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/CannonSupernova_English_960.jpg" alt="Supernova Cannon Expels Pulsar J0002" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-13</code>What could shoot out a neutron star like a cannon ball? A supernova.  About 10,000 years ago, the supernova that created the nebular remnant CTB 1 not only destroyed a massive star but blasted its newly formed neutron star core -- a pulsar -- out into the Milky Way Galaxy.  The pulsar, spinning 8.7 times a second, was discovered using downloadable software Einstein@Home searching through data taken by NASA's orbiting Fermi Gamma-Ray Observatory.  Traveling over 1,000 kilometers per second, the pulsar PSR J0002+6216 (J0002 for short) has already left the supernova remnant CTB 1, and is even fast enough to leave our Galaxy. Pictured, the trail of the pulsar is visible extending to the lower left of the supernova remnant.  The featured image is a combination of radio images from the VLA and DRAO radio observatories, as well as data archived from NASA's orbiting IRAS infrared observatory. It is well known that supernovas can act as cannons, and even that pulsars can act as cannonballs -- what is not known is how supernovas do it.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/Arp87_Hubble_1080.jpg" alt="Arp 87: Merging Galaxies from Hubble" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-11</code>This dance is to the death.  Along the way, as these two large galaxies duel, a cosmic bridge of stars, gas, and dust currently stretches over 75,000 light-years and joins them.  The bridge itself is strong evidence that these two immense star systems have passed close to each other and experienced violent tides induced by mutual gravity. As further evidence, the face-on spiral galaxy on the right, also known as NGC 3808A, exhibits many young blue star clusters produced in a burst of star formation. The twisted edge-on spiral on the left (NGC 3808B) seems to be wrapped in the material bridging the galaxies and surrounded by a curious polar ring. Together, the system is known as Arp 87 and morphologically classified, technically, as peculiar. While such interactions are drawn out over billions of years, repeated close passages should ultimately result in the death of one galaxy in the sense that only one galaxy will eventually result. Although this scenario does look peculiar, galactic mergers are thought to be common, with Arp 87 representing a stage in this inevitable process. The Arp 87 pair are about 300 million light-years distant toward the constellation Leo. The prominent edge-on spiral galaxy at the far left appears to be a more distant background galaxy and not involved in the on-going merger.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/pia23346-16_1024.jpg" alt="Curiosity at Teal Ridge" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-08</code>Part of a 360 degree panorama, this view looks out from the Mars rover Curiosity's current location on the Red Planet dubbed Teal Ridge. The mosaicked scene was captured by the rover's Mastcam on Earth calendar date June 18, 2019. That corresponds to Curiosity's sol 2440, or 2,440th martian day on the surface. Since landing seven years ago on August 6, 2012 in Gale Crater, Curiosity has traveled some 21 kilometers (13 miles). On the right, the rover's tracks lead back toward Vera Rubin Ridge with the Gale Crater rim visible in the distance. The robotic rover leaves wheel tracks about 3 meters (10 feet) apart. During its mission, Curiosity has had great successes exploring the history of water in the martian environment. In fact, NASA's Mars 2020 rover is largely based on the Mars Curiosity rover design.   Watch: Perseid Meteor Shower</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/VoidMap_Tully_960.jpg" alt="The Local Void in the Nearby Universe" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-06</code>What does our region of the Universe look like? Since galaxies are so spread out over the sky, and since our Milky Way Galaxy blocks part of the distant sky, it has been hard to tell. A new map has been made, however, using large-scale galaxy motions to infer what massive objects must be gravitating in the nearby universe. The featured map, spanning over 600 million light years on a side, shows that our Milky Way Galaxy is on the edge of the Virgo Cluster of Galaxies, which is connected to the Great Attractor -- an even larger grouping of galaxies. Also nearby are the massive Coma Cluster and the extensive Perseus-Pisces Supercluster. Conversely, we are also on the edge of huge region nearly empty of galaxies known as the Local Void.  The repulsive push by the Local Void combined with the gravitational pull toward the elevated galaxy density on the other side of the sky explains part of the mysteriously high speed our Galaxy has relative to the cosmic microwave background -- but not all.  To explore the local universe yourself, as determined by Cosmicflows-3, you are invited to zoom in and spin around this interactive 3D visualization.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/SN1994D_Hubble_960.jpg" alt="Rumors of a Dark Universe" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-04</code>Twenty-one years ago results were first presented indicating that most of the energy in our universe is not in stars or galaxies but is tied to space itself.  In the language of cosmologists, a large cosmological constant -- dark energy -- was directly implied by new distant supernova observations.  Suggestions of a cosmological constant were not new -- they have existed since the advent of modern relativistic cosmology. Such claims were not usually popular with astronomers, though, because dark energy was so unlike known universe components, because dark energy's abundance appeared limited by other observations, and because less-strange cosmologies without a significant amount of dark energy had previously done well in explaining the data. What was exceptional here was the seemingly direct and reliable method of the observations and the good reputations of the scientists conducting the investigations. Over the two decades, independent teams of astronomers have continued to accumulate data that appears to confirm the existence of dark energy and the unsettling result of a presently accelerating universe. In 2011, the team leaders were awarded the Nobel Prize in Physics for their work.  The featured picture of a supernova that occurred in 1994 on the outskirts of a spiral galaxy was taken by one of these collaborations.    News: APOD is now available via Facebook in Hindi.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/MimasPIA17213_fig1_1024.jpg" alt="Mimas in Saturnlight" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-03</code>Peering from the shadows, the Saturn-facing hemisphere of Mimas lies in near darkness alongside a dramatic sunlit crescent. The mosaic was captured near the Cassini spacecraft's final close approach on January 30, 2017. Cassini's camera was pointed in a nearly sunward direction only 45,000 kilometers from Mimas. The result is one of the highest resolution views of the icy, crater-pocked, 400 kilometer diameter moon. An enhanced version better reveals the Saturn-facing hemisphere of the synchronously rotating moon lit by sunlight reflected from Saturn itself. To see it, slide your cursor over the image (or follow this link). Other Cassini images of Mimas include the small moon's large and ominous Herschel Crater.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1908/g292chandra.jpg" alt="Elements in the Aftermath" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-08-01</code>Massive stars spend their brief lives furiously burning nuclear fuel. Through fusion at extreme temperatures and densities surrounding the stellar core, nuclei of light elements like Hydrogen and Helium are combined to heavier elements like Carbon, Oxygen, etc. in a progression which ends with Iron. So a supernova explosion, a massive star's inevitable and spectacular demise, blasts back into space debris enriched in heavier elements to be incorporated into other stars and planets and people. This detailed false-color x-ray image from the orbiting Chandra Observatory shows such a hot, expanding stellar debris cloud about 36 light-years across. Cataloged as G292.0+1.8, this young supernova remnant is about 20,000 light-years distant toward the southern constellation Centaurus. Light from the inital supernova explosion reached Earth an estimated 1,600 years ago. Bluish colors highlight filaments of the mulitmillion degree gas which are exceptionally rich in Oxygen, Neon, and Magnesium. This enriching supernova also produced a pulsar in its aftermath, a rotating neutron star remnant of the collapsed stellar core. The stunning image was released as part of the 20th anniversary celebration of the Chandra X-ray Observatory.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/M82_HubbleNobre_960.jpg" alt="M82: Galaxy with a Supergalactic Wind" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-23</code>Why is the Cigar Galaxy billowing red smoke?  M82, as this starburst galaxy is also known, was stirred up by a recent pass near large spiral galaxy M81.  This doesn't fully explain the source of the red-glowing outwardly expanding gas and dust, however.  Evidence indicates that this gas and dust is being driven out by the combined emerging particle winds of many stars, together creating a galactic superwind.  The dust particles are thought to originate in M82's interstellar medium and are actually similar in size to particles in cigar smoke.  The featured photographic mosaic highlights a specific color of red light strongly emitted by ionized hydrogen gas, showing detailed filaments of this gas and dust.  The filaments extend for over 10,000 light years. The 12-million light-year distant Cigar Galaxy is the brightest galaxy in the sky in infrared light, and can be seen in visible light with a small telescope towards the constellation of the Great Bear (Ursa Major).   APOD in other languages: Arabic, Catalan, Chinese (Beijing), Chinese (Taiwan), Croatian, Czech, Dutch, Farsi, French, French, German, Hebrew, Indonesian, Japanese, Korean, Montenegrin, Polish, Russian, Serbian, Slovenian,  Spanish and Ukrainian</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/AldrinSeismometer_Apollo11_960.jpg" alt="Moonquakes Surprisingly Common" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-21</code>Why are there so many moonquakes?   Analyses of seismometers left on the moon by the Apollo moon landings reveals a surprising number of moonquakes occurring within 100 kilometers of the surface.   In fact, 62 moonquakes were detected in data recorded between 1972 and 1977.   Many of these moonquakes are not only strong enough to move furniture in a lunar apartment, but the stiff rock of the moon continues to vibrate for many minutes, significantly longer than the softer rock earthquakes on Earth.   The cause of the moonquakes remains unknown, but a leading hypothesis is the collapse of underground faults. Regardless of the source, future moon dwellings need to be built to withstand the frequent shakings.   Pictured here 50 years ago today, Apollo 11 astronaut Buzz Aldrin stands beside a recently deployed lunar seismometer, looking back toward the lunar landing module.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/a11pan1040226lftsm600.jpg" alt="Apollo 11 Landing Panorama" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-20</code>Have you seen a panorama from another world lately? Assembled from high-resolution scans of the original film frames, this one sweeps across the magnificent desolation of the Apollo 11 landing site on the Moon's Sea of Tranquility. The images were taken by Neil Armstrong looking out his window of the Eagle Lunar Module fifty years ago, shortly after the July 20, 1969 landing. The frame at the far left (AS11-37-5449) is the first picture taken by a person on another world. Toward the south, thruster nozzles can be seen in the foreground on the left, while at the right, the shadow of the Eagle is visible to the west. For scale, the large, shallow crater on the right has a diameter of about 12 meters. Frames taken from the Lunar Module windows about an hour and a half after landing, before walking on the lunar surface, were intended to initially document the landing site in case an early departure was necessary.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/apollo11TranquilitybasePan600h.jpg" alt="Tranquility Base Panorama" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-19</code>On July 20, 1969 the Apollo 11 lunar module Eagle safely touched down on the Moon. It landed near the southwestern corner of the Moon's Mare Tranquillitatis at a landing site dubbed Tranquility Base. This panoramic view of Tranquility Base was constructed from the historic photos taken from the lunar surface. On the far left astronaut Neil Armstrong casts a long shadow with Sun is at his back and the Eagle resting about 60 meters away ( AS11-40-5961). He stands near the rim of 30 meter-diameter Little West crater seen here to the right ( AS11-40-5954). Also visible in the foreground is the top of the camera intended for taking stereo close-ups of the lunar surface.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/moon_eclipse_span1066.jpg" alt="Shadowed Moon and Mountain" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-18</code>On July 16 the Moon celebrated the 50th anniversary of the launch of Apollo 11 with a lunar eclipse visible from much of planet Earth. In this view part of the lunar disk is immersed in Earth's dark, reddened umbral shadow. Near the maximum eclipse phase, it just touches down along a mountain ridge. The rugged Tyrolean nightscape was recorded after moonrise south of Innsbruck, Austria with a dramatically lit communication tower along the ridgeline. Of course eclipses rarely travel alone. This partial lunar eclipse was at the Full Moon following July 2nd's New Moon and total eclipse of the Sun.</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/xc1SzgGhMKc?start=850" alt="Apollo 11: Descent to the Moon" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-17</code>It had never been done before. But with the words "You're Go for landing", 50 years ago this Saturday, Apollo 11 astronauts Aldrin and Armstrong were cleared to make the first try. The next few minutes would contain more than a bit of drama, as an unexpected boulder field and an unacceptably sloping crater loomed below.  With fuel dwindling, Armstrong coolly rocketed the lander above the lunar surface as he looked for a clear and flat place to land.  With only seconds of fuel remaining, and with the help of Aldrin and mission control calling out data, Armstrong finally found a safe spot -- and put the Eagle down.  Many people on Earth listening to the live audio felt great relief on hearing "The Eagle has landed", and great pride knowing that for the first time ever, human beings were on the Moon. Combined in the featured descent video are two audio feeds, a video feed similar to what the astronauts saw, captions of the dialog, and data including the tilt of the Eagle lander. The video concludes with the panorama of the lunar landscape visible outside the Eagle. A few hours later, hundreds of millions of people across planet Earth, drawn together as a single species, watched fellow humans walk on the Moon.   NASA Remembers: Apollo 50th: Next Giant Le</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/yxer_vweB5g?rel=0" alt="Apollo 11 Launches Humans to the Moon" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-16</code>verybody saw the Moon. Nobody had ever been there.  Humans across planet Earth watched in awe 50 years ago today as a powerful Saturn V rocket attempted to launch humans -- to the Moon. Some in space flight guessed that the machinery was so complex, that so many things had to go right for it to work, that Apollo 11 would end up being another useful dress rehearsal for a later successful Moon-landing mission.  But to the Moon they went. The featured video starts by showing astronauts Aldrin, Armstrong, and Collins making their way to the waiting rocket. As the large and mighty Saturn V launched, crowds watched from Cape Canaveral in Florida, USA and on television around the world.  The events that unfolded over the next few days, including a dramatic moon walk 50 years ago this Saturday, will forever be remembered as a milestone in human history and an unrivaled demonstration of human ingenuity.  This week, many places around the world are planning celebrations of the 50th anniversary of the first humans landing on the Moon.    NASA Remembers: Apollo 50th: Next Giant Le</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/aiFD_LBx2nM?rel=0" alt="4000 Exoplanets" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-10</code>Over 4000 planets are now known to exist outside our Solar System. Known as exoplanets, this milestone was passed last month, as recorded by NASA's Exoplanet Archive. The featured video highlights these exoplanets in sound and light, starting chronologically from the first confirmed detection in 1992.  The entire night sky is first shown compressed with the central band of our Milky Way Galaxy making a giant U.  Exoplanets detected by slight jiggles in their parents-star's colors (radial velocity) appear in pink, while those detected by slight dips in their parent star's brightness (transit) are shown in purple. Further, those exoplanets imaged directly appear in orange, while those detected by gravitationally magnifying the light of a background star (microlensing) are shown in green.  The faster a planet orbits its parent star, the higher the accompanying tone played. The retired Kepler satellite has discovered about half of these first 4000 exoplanets in just one region of the sky, while the new TESS mission is on track to find even more, all over the sky, orbiting the brightest nearby stars.  Finding exoplanets not only helps humanity to better understand the potential prevalence of life elsewhere in the universe, but also how our Earth and Solar System were formed.   Follow APOD on Instagram in: English, Indonesian, or Persian</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1808/GCenter_MeerKAT_1080.jpg" alt="The Galactic Center in Radio from MeerKAT" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-08</code>What's happening at the center of our galaxy? It's hard to tell with optical telescopes since visible light is blocked by intervening interstellar dust. In other bands of light, though, such as radio, the galactic center can be imaged and shows itself to be quite an interesting and active place.  The featured picture shows the inaugural image of the MeerKAT array of 64 radio dishes just completed in South Africa. Spanning four times the angular size of the Moon (2 degrees), the image is impressively vast, deep, and detailed.  Many known sources are shown in clear detail, including many with a prefix of Sgr, since the Galactic Center is in the direction of the constellation Sagittarius.  In our Galaxy's Center lies Sgr A, found here just to the right of the image center, which houses the Milky Way's central supermassive black hole.  Other sources in the image are not as well understood, including the Arc, just to the left of  Sgr A, and numerous filamentary threads. Goals for MeerKAT include searching for radio emission from neutral hydrogen emitted in a much younger universe and brief but distant radio flashes.</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/CrescentSaturn_cassini_1080.jpg" alt="Crescent Saturn" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-07</code>Saturn never shows a crescent phase -- from Earth.  But when viewed from beyond, the majestic giant planet can show an unfamiliar diminutive sliver. This image of crescent Saturn in natural color was taken by the robotic Cassini spacecraft in 2007. The featured image captures Saturn's majestic rings from the side of the ring plane opposite the Sun -- the unilluminated side -- another vista not visible from Earth. Pictured are many of Saturn's photogenic wonders, including the subtle colors of cloud bands, the complex shadows of the rings on the planet, and the shadow of the planet on the rings. A careful eye will find the moons Mimas (2 o'clock) and Janus (4 o'clock), but the real challenge is to find Pandora (8 o'clock).  Saturn is now nearly opposite from the Sun in the Earth's sky and so can be seen in the evening starting just after sunset for the rest of the night.</figcaption></figure><figure style="order: 1;"><img src="https://www.youtube.com/embed/t9-0p9KjHv8?rel=0" alt="Robotic Dragonfly Selected to Fly Across Titan" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-03</code>If you could fly across Titan, what would you see? To find out and to better explore this exotic moon of Saturn, NASA recently green-lighted Dragonfly, a mission to Titan with plans to deploy a helicopter-like drone. Saturn's moon Titan is one of the largest moons in the Solar System and the only moon known to have a thick atmosphere and changing hydrocarbon lakes. After development, building, testing, and launch, Dragonfly is currently scheduled to reach Titan in 2034. The featured animated video envisions Dragonfly arriving at Titan, beginning its airborne exploration, landing to establishing a radio link back to Earth, and then continuing on to another trans-Titanian flight. It is hoped that Dragonfly will not only help humanity better understanding Titan's weather, chemistry, and changing landscape, but also bolster humanity's understanding of how life first developed on our young Earth.   Astrophysicists: Browse 1,900+ codes in the Astrophysics Source Code Library</figcaption></figure><figure style="order: 1;"><img src="https://apod.nasa.gov/apod/image/1907/NGC1566_Shatz_960d.jpg" alt="NGC 1566: The Spanish Dancer Spiral Galaxy" style="max-height: 250px;">
<figcaption style="max-width: 400px;"><code>2019-07-02</code>If not perfect, then this spiral galaxy is at least one of the most photogenic. An island universe containing billions of stars and situated about 40 million light-years away toward the constellation of the Dolphinfish (Dorado), NGC 1566 presents a gorgeous face-on view. Classified as a grand design spiral, NGC 1566's shows two prominent and graceful spiral arms that are traced by bright blue star clusters and dark cosmic dust lanes. Numerous Hubble Space Telescope images of NGC 1566 have been taken to study star formation, supernovas, and the spiral's unusually active center. Some of these images, stored online in the Hubble Legacy Archive, were freely downloaded, combined, and digitally processed by an industrious amateur to create the featured image. NGC 1566's flaring center makes the spiral one of the closest and brightest Seyfert galaxies, likely housing a central supermassive black hole wreaking havoc on surrounding stars and gas.   Today: Total solar eclipse visible in parts of South America</figcaption></figure></div>




```python

```
